<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<meta http-equiv="Cache-Control" content="no-cache, no-store, must-revalidate" />
<meta http-equiv="Pragma" content="no-cache" />
<meta http-equiv="Expires" content="0" />
<link href="users.css" rel="stylesheet" type="text/css" media="screen" />
</head>
<?php 
require('../assets/inc/ldapConnect.php');
require('loadUser.php');

	$sr=ldap_list($ds,"cn=Modules","(&(objectclass=Module)(modulestatus=0)(|(moduletype=1)(moduletype=10)(moduletype=11)(moduletype=12)(moduletype=17)(moduletype=18)(moduletype=19)(moduletype=3)(moduletype=4)(moduletype=13)(moduletype=14)(moduletype=21)(moduletype=22)))");
       $info = ldap_get_entries($ds, $sr);
	$sr = ldap_search($ds,"cn=Modules","(&(objectclass=phone)(guid=$initialphone))"); $initial = ldap_get_entries($ds,$sr);
	
	$initial_phone_dn=$initial_phone_parts=$initial_phone_port=$initial_phone_module=NULL;
	if ( isset($initial[0]['dn']) && strlen($initial[0]['dn']) >=1 ) {
		$initial_phone_dn = str_replace("cn=","",$initial[0]['dn']); 
		$initial_phone_parts = explode(",",$initial_phone_dn);
					
		$initial_phone_port   = (isset($initial_phone_parts[0])) ? $initial_phone_parts[0] : NULL; 
		$initial_phone_module = (isset($initial_phone_parts[1])) ? $initial_phone_parts[1] : NULL;
	}

?>
<body>
<!-- Element to pop up -->
<div style='background-color:#EBEBEB; border: 4px solid black; padding: 5px; height: 565px; width: 1015px;'>

<div id="wrapper">
        <ul id="tabs">
            <li class="active">User</li>
            <li>Details</li>
			<li>Forwarding</li>
			<li>Licences</li>
			<li>Favourites</li>
        </ul>
        <ul id="tab">
		<form id='new_user'>
		<!-- first tab -->
            <li class="active">
                <h2><span id='userFormIcon' class=<?php echo $userClass ?>></span> <span id='userFormText'><?php if (strlen($userName) >= 1) echo "'" . $userName . "' "; echo $userText ?></span></h2>
				
				<!-- #left -->
				<div class="colLeft">
					<div class='field'>
						<label for="cn">User Name</label>
						<input type='text' id='cn' name='cn' value='<?php echo $usercn ?>' >
						<span class='information'>PLEASE ENTER EXTENSION USERNAME</span>
					</div>
					<div class='field'>
						<label for="telephonenumber">Telephone Number</label>
						<input type='text' id='telephonenumber' name='telephonenumber' value='<?php echo $telephonenumber ?>' >
						<span class='information'>PLEASE ENTER EXTENSION TELEPHONE NUMBER</span>
					</div>
					<div class='field'>
						<label for="description">Description</label>
						<input type='text' id='description' name='description' value='<?php echo $description ?>' >
						<span class='information'>PLEASE ENTER EXTENSION DESCRIPTION</span>
					</div>
					<div class='field'>
						<label for="dialplan">DialPlan</label>
						<select id='dialplan' name='dialplan' value='<?php echo $dialplan ?>' >
						<option></option>
						<?php
						$sr=ldap_list($ds,"cn=dialplans","(objectclass=dialplan)");
						$info = ldap_get_entries($ds, $sr);
						for ($m=0; $m<$info['count']; $m++) {
							$cn = $info[$m]['cn'][0]; $guid = $info[$m]['guid'][0];
							if ($cn ==='Vmail') continue;
							$selected = ($guid == $dialplan) ? 'selected' : '';
							echo "<option value='$guid' $selected>$cn</option>";	
						}
						?>
						</select>
						<span class='information'>PLEASE SELECT THE USERS DIALPLAN</span>
					</div>
					
					<div class='field'>
						<label>Ex Directory</label>
						<div class='checkbox'><label for="exdirectory"><div class="switch"><input type="checkbox" name='exdirectory' id='exdirectory' value="1" <?php if ($exdirectory == "1") echo "checked" ?> /><div class="slider"></div></div></label></div>
						<span class='information'>EX DIRECTORY</span>
					</div>
				</div> 
				<!-- #left -->
				
				
				<!-- #right -->
				<div class="colRight">
					<div class='field wide'>
						<label for="givenname">First & Last Name</label>
						<input type='text' class='smallFields' id='givenname' name='givenname' value='<?php echo $firstname ?>' >
						<input type='text' class='smallFields' id='sn' name='sn' value='<?php echo $lastname ?>' >
						<span class='information'>USERS FIRST AND LAST NAMES</span>
					</div>
				
					<div class='field wide'>
						<label for="initialphonemodule">Initial Phone</label>
						<select id='initialphonemodule' name='initialphonemodule' <?php if ($usertype == 1) echo 'disabled' ?>>
							<option value='clear'></option>
							<?php
								$initial_module_guid = '';
								$sr=ldap_list($ds,"cn=Modules","(&(objectclass=Module)(modulestatus=0)(|(moduletype=1)(moduletype=10)(moduletype=11)(moduletype=12)(moduletype=13)(moduletype=14)(moduletype=17)(moduletype=18)(moduletype=19)(moduletype=22)))");
								$info = ldap_get_entries($ds, $sr);
								for ($m=0; $m<$info['count']; $m++) {				
								$cn = $info[$m]['cn'][0]; $guid = $info[$m]['guid'][0];
								if ($usertype == 1) {
									$selected = ""; 
								} elseif ($initial_phone_module == $cn) {
									$selected = "selected"; $initial_module_guid = $guid;
								} else {
									$selected = "";	
								}
								echo "<option value='$guid' $selected>$cn</option>";	
								}
							?>
						</select>
						
						<select id='initialphone' name='initialphone' <?php if ($usertype == 1) echo 'disabled' ?>>
							<option></option>
							<?php
							$multipleDevices = array('W5', 'W6', 'T53', 'T54', 'T57', 'VP59');
							if ($userMode == "editUser") {
								$sr = @ldap_list($ds,"cn=users","(&(objectclass=user)(!(initialphone=00000000-0000-0000-0000-000000000000)))", array('initialphone'));
								$info = @ldap_get_entries($ds, $sr);	$setinitialphones = array();
								for ($m=0; $m<$info['count']; $m++) {				
									$setinitialphones[] = $info[$m]['initialphone'][0];
								}
								$tmp = array_count_values($setinitialphones);
								
								$sr = @ldap_list($ds,"guid=$initial_module_guid,cn=modules","(&(objectclass=phone)(typeofphone<=3))", array('cn','guid'));
								$info = @ldap_get_entries($ds, $sr);  $modules ='';
								
								for ($m=0; $m<$info['count']; $m++) {				
									$guid = $info[$m]['guid'][0]; 
							
									$sr2 = ldap_read($ds,"cn=1,guid=$guid","objectclass=*",array('guid','pnpmodel')); 
									$info2 = ldap_get_entries($ds,$sr2);	
									$pnpmodel = (isset($info2[0]['pnpmodel'][0])) ? $info2[0]['pnpmodel'][0] : '';
									
								if (($guid == $initialphone) || (str_replace($multipleDevices, '', $pnpmodel) != $pnpmodel) || !in_array($guid, $setinitialphones)) {
			                    
									if (in_array($guid, $setinitialphones)) {
										if ($guid != $initialphone) {
										 if ((stripos($pnpmodel, 'W5') !== false && $tmp[$guid] >=5) || 
											 (stripos($pnpmodel, 'W6') !== false && $tmp[$guid] >=8) || 
											 (stripos($pnpmodel, 'T53') !== false && $tmp[$guid] >=5) || 
											 (stripos($pnpmodel, 'T54') !== false && $tmp[$guid] >=5)  || 
											 (stripos($pnpmodel, 'T57') !== false && $tmp[$guid] >=5)  || 
											 (stripos($pnpmodel, 'VP59') !== false && $tmp[$guid] >=5)) continue;
										}
									}
			                    
									$cn =  (substr($info[$m]['cn'][0],0,4)=='port') ?  chunk_split(ucfirst($info[$m]['cn'][0]), 4, ' ') : $info[$m]['cn'][0];
									$selected = ($guid == $initialphone) ? "class='initialOption' selected" : "";
									echo "<option value='$guid' $selected>$cn</option>";
									}	
                                }
								
								$sr=ldap_list($ds, "cn=UnassignedPhones", "(&(&(objectclass=UnassignedPhone)(typeofphone=2)(location=$initial_module_guid)))", array("cn","guid","typeOfPhone","location"));
								$info2 = ldap_get_entries($ds, $sr); $devices =''; $guid = '';
								
								if ($info2['count'] >0) {
									echo "<option value></option><optgroup label='Unassigned Phones'></optgroup>";
									
									for ($n=0; $n<$info2['count']; $n++) {				
										$guid = $info2[$n]['guid'][0]; 
										$cn = $info2[$n]['cn'][0];
										echo "<option value='$guid'>$cn</option>";	
									}
								}
							}
						?>
						</select>
						<span class='information'>INITIAL MODULE AND PHONE</span>
					</div>
				
					<div class='field'>
						<label>Restrict Groups</label>
						<div class='checkbox'><label for="restrictgroups"><div class="switch"><input type="checkbox" name='restrictgroups' id='restrictgroups' value="1" <?php if ($restrictgroups == "1") echo "checked" ?> /><div class="slider"></div></div></label></div>
						<span class='information'>RESTRICT USER FROM LOGGING OUT OF GROUP</span>
					</div>
				<?php if (isset($adminCompany)	&& $adminCompany === '00000000-0000-0000-0000-000000000000') {
					echo "<div class='field'>
						<label for='company'>Company</label>
						<select id='company' name='company' value='$company' >
						<option></option>";
						
						$sr=ldap_list($ds,"cn=companies","(objectclass=company)");
						$info = ldap_get_entries($ds, $sr);
						for ($m=0; $m<$info['count']; $m++) {
							$cn = $info[$m]['cn'][0]; $guid = $info[$m]['guid'][0];
							if ($cn === 'MyCompany') continue;
							$selected = ($guid == $company) ? 'selected' : '';
							echo "<option value='$guid' $selected>$cn</option>";	
						}
				?>
						
						</select>
						<span class='information'>SELECT COMPANY</span>
					</div>
					
					<div class='field'>
						<label>Call Select</label>
						<div class='checkbox'><label for="callselect"><div class="switch"><input type="checkbox" name='callselect' id='callselect' value="1" <?php if ($callselect == "1") echo "checked" ?> /><div class="slider"></div></div></label></div>
						<span class='information'>CALL SELECT</span>
					</div>
				<?php 
				} 
				?>
				</div> 
				<!-- #right -->
			</li>	
			<!-- first tab -->
			
			
			<!-- second tab -->
            <li class="warnings">
				<h2><span id='userFormIcon' class=<?php echo $userClass ?>></span> <span id='userFormText'><?php if (strlen($userName) >= 1) echo "'" . $userName . "' - Edit  "; ?>Details</span></h2>
				<!-- #left -->
				<div class="colLeft">
				
				<div class='field'>
					<label>Enable Voicemail</label>
					<div class='checkbox'><label for="voicemailenabled"><div class="switch"><input type="checkbox" name='voicemailenabled' id='voicemailenabled' value="1" <?php if ($voicemailenabled == "1") echo "checked" ?> /><div class="slider"></div></div></label></div>
					<span class='information'>ENABLE VOICEMAIL</span>
				</div>
				
				<div class='field'>
					<label for="currenthome">Voicemail Home</label>
					<select id='currenthome' name='currenthome' value='<?php echo $currenthome ?>' >
					<option></option>
					<?php
					$sr=ldap_list($ds,"cn=Modules","(&(objectclass=Module)(modulestatus=0)(|(moduletype=1)(moduletype=10)(moduletype=11)(moduletype=12)(moduletype=17)(moduletype=18)(moduletype=19)))");
					$info = ldap_get_entries($ds, $sr);
					for ($m=0; $m<$info['count']; $m++) {
						$cn = $info[$m]['cn'][0]; $guid = $info[$m]['guid'][0];
						$selected = ($guid == $currenthome) ? 'selected' : '';
						echo "<option value='$guid' $selected>$cn</option>";	
					}
					?>
					</select>
					<span class='information'>PLEASE SELECT THE USERS VOICEMAIL HOME</span>
				</div>
				
				<div class='field'>
					<label for="voicemailaccesscode">Voicemail Access Code</label>
					<input type='password' id='voicemailaccesscode' name='voicemailaccesscode' value='<?php echo $voicemailaccesscode ?>' >
					<span class='information'>USERS VOICEMAIL ACCESS CODE</span>
				</div>
				
				<div class='field'>
					<label for="noanswertime">No Answer Time</label>
					<input type='text' id='noanswertime' name='noanswertime' value='<?php echo $noanswertime ?>' >
					<span class='information'>NO ANSWER TIME (DIVERT TO VOICEMAIL)</span>
				</div>
				
				<div class='field'>
					<label for="loginaccesscode">Login Access Code</label>
					<input type='password' id='loginaccesscode' name='loginaccesscode' value='<?php echo $loginaccesscode ?>' >
					<span class='information'>USERS LOGIN ACCESS CODE</span>
				</div>
				
				</div> 
				<!-- #left -->
				
				<!-- #right -->
				<div class="colRight">
				<div class='field'>
					<label for="dectline">Preferred DECT Line</label>
					<input type='text' id='dectline' name='dectline' value='<?php echo $dectline ?>' >
					<span class='information'>PREFERRED DECT LINE</span>
				</div>
				<div class='field'>
					<label for="hometelephonenumber">Home Phone Number</label>
					<input type='text' id='hometelephonenumber' name='hometelephonenumber' value='<?php echo $hometelephonenumber ?>' >
					<span class='information'>HOME TELEPHONE NUMBER</span>
				</div>
					
				<div class='field'>
					<label for="mobiletelephonenumber">Mobile Phone Number</label>
					<input type='text' id='mobiletelephonenumber' name='mobiletelephonenumber' value='<?php echo $mobiletelephonenumber ?>' >
					<span class='information'>MOBILE TELEPHONE NUMBER</span>
				</div>
				
				<div class='field wide'>
					<label for="mail">Email Address</label>
					<input type='text' id='mail' name='mail' value='<?php echo $mail ?>' >
					<span class='information'>EMAIL ADDRESS</span>
				</div>
				
				<div class='field wide'>
					<label for="logourl">Logo URL</label>
					<input type='text' id='logourl' name='logourl' value='<?php echo $logourl ?>' >
					<span class='information'>PCS PHONE LOGO URL</span>
				</div>
				

				</div> 
				<!-- #right -->
			</li>
			<!-- second tab -->
			
			<!-- third tab -->
            <li class="warnings">
				<h2><span id='userFormIcon' class=<?php echo $userClass ?>></span> <span id='userFormText'><?php if (strlen($userName) >= 1) echo "'" . $userName . "' - Edit  "; ?>Forwarding</span></h2>
				<!-- #left -->
				<div class="colFull">
				
				<?php
				// FORWARDING
				$userCount = $departmentCount = $selectUser = $selectDepartment = $selectOther = $selectHome = $selectMobile = $selectNone = '';
				if ($userMode === 'editUser') {
					
					if (strlen($followmeto) > 0) {
						//users
						$sr=ldap_search($ds,"cn=users","(&(objectclass=user)(|(cn=$followmeto)(telephonenumber=$followmeto)))", array('cn','telephonenumber'));
						$info = ldap_get_entries($ds, $sr); $userCount = ($info["count"] > 0) ? '1' : '0';	
						
						//departments
						$sr=ldap_search($ds,"cn=departments","(&(objectclass=department)(|(cn=$followmeto)(telephonenumber=$followmeto)))", array('cn','telephonenumber'));
						$info = ldap_get_entries($ds, $sr); $departmentCount = ($info["count"] > 0) ? '1' : '';
					}
					
					
						
					// plain number / name match
					if (preg_match("/^[a-zA-Z0-9 ]*$/", $followmeto)) {
						if ($userCount === '1') {
							$selectUser = 'selected';
						} elseif ($departmentCount === '1') {
							$selectDepartment = 'selected';
						} elseif (strlen($hometelephonenumber) >= '1' && $followme > 0 && str_replace(' ','',$followmeto) == str_replace(' ','',$hometelephonenumber) ) {
							$selectHome = 'selected';
						} elseif (strlen($mobiletelephonenumber) >= '1' && $followme > 0 && str_replace(' ','',$followmeto) == str_replace(' ','',$mobiletelephonenumber) ) {
							$selectMobile = 'selected';
						} elseif ($followme === '0') {
							$selectNone = 'disabled';
						} else {
							$selectOther = 'selected';
							$spanError = "error";
						}
					}
				} else if ($userMode === 'addUser') {
							$selectNone = 'disabled';
				}
				?>
				
					<div class='field wide forwarding'>
						<label for="followme">Forward</label>
						<select id='followme' name='followme'>
							<option value='0'  <?php if ($followme == '0') echo 'selected' ?> >Off</option>
							<option value='1'  <?php if ($followme == '1') echo 'selected' ?> >My Extension / DDI Calls</option>
							<option value='2'  <?php if ($followme == '2') echo 'selected' ?> >My Extension / DDI Calls & Ring my Extension</option>
							<option value='3'  <?php if ($followme == '3') echo 'selected' ?> >All Calls</option>
							<option value='4'  <?php if ($followme == '4') echo 'selected' ?> >All Calls & Ring my Extension</option>
							<option value='5'  <?php if ($followme == '5') echo 'selected' ?> >All External Calls</option>
							<option value='6'  <?php if ($followme == '6') echo 'selected' ?> >All External Calls & Ring my Extension</option>
							<option value='7'  <?php if ($followme == '7') echo 'selected' ?> >All External / Department Calls</option>
							<option value='8'  <?php if ($followme == '8') echo 'selected' ?> >All External / Department Calls & Ring my Extension</option>
							<option value='9'  <?php if ($followme == '9') echo 'selected' ?> >All Internal Calls</option>
							<option value='10' <?php if ($followme == '10') echo 'selected' ?> >All Internal Calls & Ring my Extension</option>
							<option value='11' <?php if ($followme == '11') echo 'selected' ?> >All Internal / Department Calls</option>
							<option value='12' <?php if ($followme == '12') echo 'selected' ?> >All Internal / Department Calls & Ring my Extension</option>
						<select>
						
						<b> To: </b>
						
						<select id='followmetoselect' name='followmetoselect' <?php echo $selectNone ?>>
						<option></option>
						<option value='home' <?php echo $selectHome ?> >Home Telephone Number</option>
						<option value='mobile' <?php echo $selectMobile ?> >Mobile Telephone Number</option>
						<option value='users' <?php echo $selectUser ?> >Users</option>
						<option value='departments' <?php echo $selectDepartment ?>>Departments</option>
						<option value='other' <?php echo $selectOther ?>>Other</option>
						</select>
						
						<?php
						if ($userMode === 'addUser' || $selectNone === 'disabled')
							echo "<input name='followmeto' id='followmeto' class='smallFields' readonly>";
						
						if ($userMode === 'editUser' && $selectUser === 'selected' ) {
							echo "<select name='followmeto' id='followmeto'><option></option>";
							$sr=ldap_list($ds, "cn=users","(objectclass=user)", array('cn','telephonenumber'));
							$info = ldap_get_entries($ds, $sr);
								for ($i=0; $i<$info["count"]; $i++) {
									$cn = $info[$i]['cn'][0]; $telephonenumber = $info[$i]['telephonenumber'][0];
									$selected = ($followmeto === $cn || $followmeto === $telephonenumber) ? 'selected' : '';
									echo "<option value='$telephonenumber' $selected>$cn ($telephonenumber)</option>";
								}
							echo "</select>";
						} else if ($userMode === 'editUser' && $selectDepartment === 'selected' ) {
							echo "<select name='followmeto' id='followmeto'><option></option>";
							$sr=ldap_list($ds, "cn=departments","(objectclass=department)", array('cn','telephonenumber'));
							$info = ldap_get_entries($ds, $sr);
								for ($i=0; $i<$info["count"]; $i++) {
									$cn = $info[$i]['cn'][0]; $telephonenumber = $info[$i]['telephonenumber'][0];
									$selected = ($followmeto === $cn || $followmeto === $telephonenumber) ? 'selected' : '';
									echo "<option value='$telephonenumber' $selected>$cn ($telephonenumber)</option>";
								}
							echo "</select>";
						} else if ($userMode === 'editUser' && ($selectHome === 'selected' || $selectMobile === 'selected')) {
								echo "<input name='followmeto' id='followmeto' class='smallFields' value='$followmeto' readonly>";
						} else if ($userMode === 'editUser' && $selectOther === 'selected' ) {
								echo "<input name='followmeto' id='followmeto' class='smallFields' value='$followmeto'>";
						} 
						
						?>
						<span class='information'>SET FORWARDING MODE AND DESTINATION</span>
					</div>
					
					
					<?php
					// FORWARD ON BUSY
					$userCount = $departmentCount = $selectUser = $selectDepartment = $selectOther = $selectHome = $selectMobile = $selectNone = '';
					if ($userMode === 'editUser') {
						
						if (strlen($forwardonbusyto) > 0) {

							//users
							$sr=ldap_search($ds,"cn=users","(&(objectclass=user)(|(cn=$forwardonbusyto)(telephonenumber=$forwardonbusyto)))", array('cn','telephonenumber'));
							$info = ldap_get_entries($ds, $sr); $userCount = ($info["count"] > 0) ? '1' : '0';	
							//departments
							$sr=ldap_search($ds,"cn=departments","(&(objectclass=department)(|(cn=$forwardonbusyto)(telephonenumber=$forwardonbusyto)))", array('cn','telephonenumber'));
							$info = ldap_get_entries($ds, $sr); $departmentCount = ($info["count"] > 0) ? '1' : '';
						
						}
						
						// plain number / name match
						if (preg_match("/^[a-zA-Z0-9 ]*$/", $forwardonbusyto)) {
							if ($userCount === '1') {
								$selectUser = 'selected';
							} elseif ($departmentCount === '1') {
								$selectDepartment = 'selected';
							} elseif (strlen($hometelephonenumber) >= '1' && $forwardonbusy > 0  && str_replace(' ','',$forwardonbusyto) == str_replace(' ','',$hometelephonenumber) ) {
								$selectHome = 'selected';
							} elseif (strlen($mobiletelephonenumber) >= '1' && $forwardonbusy > 0 && str_replace(' ','',$forwardonbusyto) == str_replace(' ','',$mobiletelephonenumber) ) {
								$selectMobile = 'selected';
							} elseif ($forwardonbusy === '0') {
								$selectNone = 'disabled';
							} else {
								$selectOther = 'selected';
								$spanError = "error";
							}
						}
					} else if ($userMode === 'addUser') {
								$selectNone = 'disabled';
					}
					?>
					
				
					<br><div class='field wide forwarding'>
						<label for="forwardonbusy">Forward On Busy</label>
						<select id='forwardonbusy' name='forwardonbusy'>
							<option value='0' <?php if ($forwardonbusy == '0') echo 'selected' ?> >None</option>
							<option value='1' <?php if ($forwardonbusy == '1') echo 'selected' ?> >Internal&amp;External</option>
							<option value='2' <?php if ($forwardonbusy == '2') echo 'selected' ?> >Internal</option>
							<option value='3' <?php if ($forwardonbusy == '3') echo 'selected' ?> >External</option>
						<select>
						
						<b> To: </b>
					
						<select id='forwardonbusytoselect' name='forwardonbusytoselect' <?php echo $selectNone ?>>
						<option></option>
						<option value='home' <?php echo $selectHome ?> >Home Telephone Number</option>
						<option value='mobile' <?php echo $selectMobile ?> >Mobile Telephone Number</option>
						<option value='users' <?php echo $selectUser ?> >Users</option>
						<option value='departments' <?php echo $selectDepartment ?>>Departments</option>
						<option value='other' <?php echo $selectOther ?>>Other</option>
						</select>
						
						<?php
						if ($userMode === 'addUser' || $selectNone === 'disabled')
							echo "<input name='forwardonbusyto' id='forwardonbusyto' class='smallFields' readonly>";
						
						if ($userMode === 'editUser' && $selectUser === 'selected' ) {
							echo "<select name='forwardonbusyto' id='forwardonbusyto'><option></option>";
							$sr=ldap_list($ds, "cn=users","(objectclass=user)", array('cn','telephonenumber'));
							$info = ldap_get_entries($ds, $sr);
								for ($i=0; $i<$info["count"]; $i++) {
									$cn = $info[$i]['cn'][0]; $telephonenumber = $info[$i]['telephonenumber'][0];
									$selected = ($forwardonbusyto === $cn || $forwardonbusyto === $telephonenumber) ? 'selected' : '';
									echo "<option value='$telephonenumber' $selected>$cn ($telephonenumber)</option>";
								}
							echo "</select>";
						} else if ($userMode === 'editUser' && $selectDepartment === 'selected' ) {
							echo "<select name='forwardonbusyto' id='forwardonbusyto'><option></option>";
							$sr=ldap_list($ds, "cn=departments","(objectclass=department)", array('cn','telephonenumber'));
							$info = ldap_get_entries($ds, $sr);
								for ($i=0; $i<$info["count"]; $i++) {
									$cn = $info[$i]['cn'][0]; $telephonenumber = $info[$i]['telephonenumber'][0];
									$selected = ($forwardonbusyto === $cn || $forwardonbusyto === $telephonenumber) ? 'selected' : '';
									echo "<option value='$telephonenumber' $selected>$cn ($telephonenumber)</option>";
								}
							echo "</select>";
						} else if ($userMode === 'editUser' && ($selectHome === 'selected' || $selectMobile === 'selected')) {
								echo "<input name='forwardonbusyto' id='forwardonbusyto' class='smallFields' value='$forwardonbusyto' readonly>";
						} else if ($userMode === 'editUser' && $selectOther === 'selected' ) {
								echo "<input name='forwardonbusyto' id='forwardonbusyto' class='smallFields' value='$forwardonbusyto'>";
						} 
						
						?>
						
						<span class='information'>SET FORWARD ON BUSY MODE AND DESTINATION</span>
					</div>
					
					
					<?php
					// FORWARD ON NO ANSWER
					$userCount = $departmentCount = $selectUser = $selectDepartment = $selectOther = $selectHome = $selectMobile = $selectNone = '';
					if ($userMode === 'editUser') {
						
						if (strlen($forwardonnoanswerto) > 0) {

							//users
							$sr=ldap_search($ds,"cn=users","(&(objectclass=user)(|(cn=$forwardonnoanswerto)(telephonenumber=$forwardonnoanswerto)))", array('cn','telephonenumber'));
							$info = ldap_get_entries($ds, $sr); $userCount = ($info["count"] > 0) ? '1' : '0';	
							//departments
							$sr=ldap_search($ds,"cn=departments","(&(objectclass=department)(|(cn=$forwardonnoanswerto)(telephonenumber=$forwardonnoanswerto)))", array('cn','telephonenumber'));
							$info = ldap_get_entries($ds, $sr); $departmentCount = ($info["count"] > 0) ? '1' : '';
						
						}
						// plain number / name match
						if (preg_match("/^[a-zA-Z0-9 ]*$/", $forwardonnoanswerto)) {
							if ($userCount === '1') {
								$selectUser = 'selected';
							} elseif ($departmentCount === '1') {
								$selectDepartment = 'selected';
							} elseif (strlen($hometelephonenumber) >= '1' && $forwardonnoanswer > 0  && str_replace(' ','',$forwardonnoanswerto) == str_replace(' ','',$hometelephonenumber) ) {
								$selectHome = 'selected';
							} elseif (strlen($mobiletelephonenumber) >= '1' && $forwardonnoanswer > 0 && str_replace(' ','',$forwardonnoanswerto) == str_replace(' ','',$mobiletelephonenumber) ) {
								$selectMobile = 'selected';
							} elseif ($forwardonnoanswer === '0') {
								$selectNone = 'disabled';
							} else {
								$selectOther = 'selected';
								$spanError = "error";
							}
						}
					} else if ($userMode === 'addUser') {
								$selectNone = 'disabled';
					}
					?>
					
					
					<br><div class='field wide forwarding'>
						<label for="forwardonnoanswer">Forward On No Answer</label>
						<select id='forwardonnoanswer' name='forwardonnoanswer'>
							<option value='0' <?php if ($forwardonnoanswer == '0') echo 'selected' ?> >None</option>
							<option value='1' <?php if ($forwardonnoanswer == '1') echo 'selected' ?> >Internal&amp;External</option>
							<option value='2' <?php if ($forwardonnoanswer == '2') echo 'selected' ?> >Internal</option>
							<option value='3' <?php if ($forwardonnoanswer == '3') echo 'selected' ?> >External</option>
						<select>
				
						<b> To: </b>
				
						<select id='forwardonnoanswertoselect' name='forwardonnoanswertoselect' <?php echo $selectNone ?>>
						<option></option>
						<option value='home' <?php echo $selectHome ?> >Home Telephone Number</option>
						<option value='mobile' <?php echo $selectMobile ?> >Mobile Telephone Number</option>
						<option value='users' <?php echo $selectUser ?> >Users</option>
						<option value='departments' <?php echo $selectDepartment ?>>Departments</option>
						<option value='other' <?php echo $selectOther ?>>Other</option>
						</select>
						
						<?php
						if ($userMode === 'addUser' || $selectNone === 'disabled')
							echo "<input name='forwardonnoanswerto' id='forwardonnoanswerto' class='smallFields' readonly>";
						
						if ($userMode === 'editUser' && $selectUser === 'selected' ) {
							echo "<select name='forwardonnoanswerto' id='forwardonnoanswerto'><option></option>";
							$sr=ldap_list($ds, "cn=users","(objectclass=user)", array('cn','telephonenumber'));
							$info = ldap_get_entries($ds, $sr);
								for ($i=0; $i<$info["count"]; $i++) {
									$cn = $info[$i]['cn'][0]; $telephonenumber = $info[$i]['telephonenumber'][0];
									$selected = ($forwardonnoanswerto === $cn || $forwardonnoanswerto === $telephonenumber) ? 'selected' : '';
									echo "<option value='$telephonenumber' $selected>$cn ($telephonenumber)</option>";
								}
							echo "</select>";
						} else if ($userMode === 'editUser' && $selectDepartment === 'selected' ) {
							echo "<select name='forwardonnoanswerto' id='forwardonnoanswerto'><option></option>";
							$sr=ldap_list($ds, "cn=departments","(objectclass=department)", array('cn','telephonenumber'));
							$info = ldap_get_entries($ds, $sr);
								for ($i=0; $i<$info["count"]; $i++) {
									$cn = $info[$i]['cn'][0]; $telephonenumber = $info[$i]['telephonenumber'][0];
									$selected = ($forwardonnoanswerto === $cn || $forwardonnoanswerto === $telephonenumber) ? 'selected' : '';
									echo "<option value='$telephonenumber' $selected>$cn ($telephonenumber)</option>";
								}
							echo "</select>";
						} else if ($userMode === 'editUser' && ($selectHome === 'selected' || $selectMobile === 'selected')) {
								echo "<input name='forwardonnoanswerto' id='forwardonnoanswerto' class='smallFields' value='$forwardonnoanswerto' readonly>";
						} else if ($userMode === 'editUser' && $selectOther === 'selected' ) {
								echo "<input name='forwardonnoanswerto' id='forwardonnoanswerto' class='smallFields' value='$forwardonnoanswerto'>";
						} 
						
						?>
						
						<span class='information'>SET FORWARD ON NO ANSWER MODE AND DESTINATION</span>
					</div>
				
				</div> 				
				
				<div class="colLeft">
					<div class='field'>
					<label for="callwaiting">Call Waiting</label>
						<select id='callwaiting' name='callwaiting'>
							<option value='0' <?php if ($callwaiting =='0') echo 'selected' ?> >Disable</option>
							<option value='1' <?php if ($callwaiting =='1') echo 'selected' ?> >Enable</option>
							<option value='2' <?php if ($callwaiting =='2') echo 'selected' ?> >Phone Tools</option>
							<option value='3' <?php if ($callwaiting =='3') echo 'selected' ?> >No Beep</option>
						<select>
						<span class='information'>SET CALL WAITING</span>
					</div>	
				</div>	
				
				<div class="colRight">
					<div class='field'>
						<label>Do Not Disturb</label>
						<div class='checkbox'><label for="donotdisturb"><div class="switch"><input type="checkbox" name='donotdisturb' id='donotdisturb' value="1" <?php if ($donotdisturb == "1") echo "checked" ?> /><div class="slider"></div></div></label></div>
						<span class='information'>ENABLE DO NOT DISTURB</span>
					</div>	
				</div>	

				
				
				<!-- #right -->
				
            </li>
			<!-- Third tab -->
			
			
			<!-- Fourth tab -->
            <li class="warnings">
				<h2><span id='userFormIcon' class=<?php echo $userClass ?>></span> <span id='userFormText'><?php if (strlen($userName) >= 1) echo "'" . $userName . "' - Edit  "; ?>Licences</span></h2>
				<!-- #left -->
				<!-- #left -->
				<div class="colLeft">
				
					<div class='field'>
						<label for="usertype">User Licence Type</label>
						<select id='usertype' name='usertype'>
						<?php
						if ($userMode === 'addUser') {
							echo "<option value=''></option>";
						}
						?>
							<option value='0' <?php if ($usertype == '0') echo 'selected' ?> >IP</option>
							<option value='2' <?php if ($usertype == '2') echo 'selected' ?> >Analogue</option>
							<option value='1' <?php if ($usertype == '1') echo 'selected' ?> >Virtual</option>
						<select>
						<span class='information'>USER LICENCE TYPE</span>
					</div>
				
				
					<div class='field'>
						<label>Voicemail Box Licence</label>
						<div class='checkbox'><label for="messageboxlicense"><div class="switch"><input type="checkbox" name='messageboxlicense' id='messageboxlicense' value="1" <?php if ($messageboxlicense == "1") echo "checked" ?> /><div class="slider"></div></div></label></div>
						<span class='information'>LICENCE AND ENABLE VOICEMAIL BOX</span>
					</div>
					
					<div class='field'>
						<label>SIP Phone Licence</label>
						<div class='checkbox'><label for="siplicense"><div class="switch"><input type="checkbox" name='siplicense' id='siplicense' value="1" <?php if ($siplicense == "1") echo "checked" ?> /><div class="slider"></div></div></label></div>
						<span class='information'>ENABLE SIP PHONE LICENCE</span>
					</div>	
					
					<div class='field'>
						<label>iPCS Licence</label>
						<div class='checkbox'><label for="ipcslicense"><div class="switch"><input type="checkbox" name='ipcslicense' id='ipcslicense' value="1" <?php if ($ipcslicense == "1") echo "checked" ?> /><div class="slider"></div></div></label></div>
						<span class='information'>ENABLE iPCS LICENCE</span>
					</div>
					
					<div class='field'>
						<label>Web Portal Licence</label>
						<div class='checkbox'><label for="totalcontrollicense"><div class="switch"><input type="checkbox" name='totalcontrollicense' id='totalcontrollicense' value="1" <?php if ($totalcontrollicense == "1") echo "checked" ?> /><div class="slider"></div></div></label></div>
						<span class='information'>ENABLE WEB PORTAL LICENCE</span>
					</div>
				</div> 
				<!-- #left -->
				
				<!-- #right -->
				<div class="colRight">
				
					<div class='field'>
						<label>Navigate Soft Phone Licence</label>
						<div class='checkbox'><label for="navigatesoftphonelicense"><div class="switch"><input type="checkbox" name='navigatesoftphonelicense' id='navigatesoftphonelicense' value="1" <?php if ($navigatesoftphonelicense == "1") echo "checked" ?> /><div class="slider"></div></div></label></div>
						<span class='information'>ENABLE NAVIGATE SOFTPHONE LICENCE</span>
					</div>
					
					<div class='field'>
						<label>Navigate Skype for Business Licence</label>
						<div class='checkbox'><label for="navigatesfblicense"><div class="switch"><input type="checkbox" name='navigatesfblicense' id='navigatesfblicense' value="1" <?php if ($navigatesfblicense == "1") echo "checked" ?> /><div class="slider"></div></div></label></div>
						<span class='information'>ENABLE NAVIGATE SKYPE FOR BUSINESS LICENCE</span>
					</div>
				
					<div class='field'>
						<label for="navigateoutlooklicense">Navigate Outlook Licence</label>
						<select id='navigateoutlooklicense' name='navigateoutlooklicense'>
							<option value='0' <?php if ($navigateoutlooklicense == '0') echo 'selected' ?> >None</option>
							<option value='1' <?php if ($navigateoutlooklicense == '1') echo 'selected' ?> >Yes</option>
							<option value='2' <?php if ($navigateoutlooklicense == '2') echo 'selected' ?> >Calendar Disabled</option>
						<select>
						<span class='information'>SET NAVIGATE OUTLOOK LICENCE MODE</span>
					</div>
					
					<div class='field'>
						<label for="operatorconsolelicense">Operator Console Licence</label>
						<select id='operatorconsolelicense' name='operatorconsolelicense'>
							<option value='0' <?php if ($operatorconsolelicense == '0') echo 'selected' ?> >None</option>
							<option value='1' <?php if ($operatorconsolelicense == '1') echo 'selected' ?> >Yes</option>
							<option value='2' <?php if ($operatorconsolelicense == '2') echo 'selected' ?> >PCS Partner Only</option>
						<select>
						<span class='information'>SET OPERATOR CONSOLE MODE</span>
					</div>
				
					<div class='field'>
						<label>Disabled (lack of licence)</label>
						<div class='checkbox'><label for="disabled"><div class="switch"><input type="checkbox" name='disabled' id='disabled' value="1" <?php if ($disabled == "1") echo "checked" ?> /><div class="slider"></div></div></label></div>
						<span class='information'>DISABLED (LACK OF LICENCE)</span>
					</div>	
				
				</div> 
				<!-- #right -->
				
				<input type='hidden' id='userMode' name='userMode' value='<?php echo $userMode ?>'>
				<input type='hidden' id='userName' name='userName' value='<?php echo $userName ?>'>
				<input type='hidden' id='userGuid' name='userGuid' value='<?php echo $userGuid ?>'>
				<input type='hidden' id='guid' name='guid' value=''>
			</form>
				
			</li>
			<!-- Fourth tab -->
			
			
			
			<!-- Fifth tab -->
            <li>
				<h2><span id='userFormIcon' class=<?php echo $userClass ?>></span> <span id='userFormText'><?php if (strlen($userName) >= 1) echo "'" . $userName . "' - Edit  "; ?>Favourites</span></h2>
				<!-- #left -->
				<div class='scroller'>
				<div class="colFull">
				
			<div class='speedDials'>
			<label>Favourites</label><br/>
			
			<form id='frm1' name='frm1'>
			<table id="speedDialFrm" cellspacing="0" cellpadding="10" >
                <thead id="sprintlist_header">
                    <tr>
                        <th>Telephone Number</th>
						<th>Description</th>
						<th>Action</th>
                    </tr>
                </thead>
                <tbody>
                   
				<?php
				if ($userMode === 'editUser') {
				$sr=ldap_list($ds,"cn=$usercn, cn=Users", "(objectclass=speeddial)", array('telephonenumber','description','guid','shortcode'));
				$info = ldap_get_entries($ds, $sr);
				for ($m=0; $m<$info['count']; $m++) {	
				
				//$shortcode = (isset($info[$m]['shortcode'][0]) && strlen($info[$m]['shortcode'][0]) >=1) ? $info[$m]['shortcode'][0] : 'G:996699';
				if (isset($info[$m]['shortcode'][0])) {
					if (stripos($info[$m]['shortcode'][0], 'PRI') !== false ) {
						$orVal = str_replace('PRI:', '', $info[$m]['shortcode'][0]);
						$shortcode = "G:996699,$orVal" ;
					} else if (strlen($info[$m]['shortcode'][0]) >=1 ) { 
						$shortcode = $info[$m]['shortcode'][0];
					} else {
						$shortcode = 'G:996699';
					}
						
				}
				$telephonenumber = $info[$m]['telephonenumber'][0];
				$guid = $info[$m]['guid'][0];
				$description = $info[$m]['description'][0];
				$headerValue = explode(',' ,str_replace('GH:','', $shortcode));
				$groupID = (isset($headerValue[0])) ? $headerValue[0] : '';
				$orderPriority = (isset($headerValue[1])) ? $headerValue[1] : '';
				
				if (substr($shortcode, 0, 3) === 'GH:') {
					echo "<tr id='$m' data-header='GH:$groupID' data-order='$orderPriority' data-guid='$guid' class='group_heading nodrag'>";
                        echo "<td><img src='../assets/images/folder-icon.png'><input type='text' maxlength='16' id='group$m' value='$description' class='group_header'></td>";
						echo "<td>Order: <span id='orderPriority$m'>$orderPriority</span></td>";
						echo "<td><img class='cursor' id='moveDown' src='../assets/images/down.png' /> <img id='moveUp' class='cursor' src='../assets/images/up.png' /> <img id='headerDelete' class='cursor' src='../assets/images/delete.png' /></td>";
                    echo "</tr>";
					
				} else {
				
				if (stripos($telephonenumber, 'slot') !== false) {
					$disabled = "readonly";
					echo "<tr id='$m' data-speeddial='$groupID' data-order='$orderPriority' class='toggler_row nodrag'>";	
				} else {
					$disabled = "";
					echo "<tr id='$m' data-speeddial='$groupID' data-order='$orderPriority' class='toggler_row'>";
				}

				
				echo "<td>
						<input name='sp_id[]' id='spguid$m' type='hidden' value='$guid' $disabled/>
						<input name='sp_number[]' id='spnumber$m' type='text' class='smallFields' value='$telephonenumber' $disabled/>
						</td>
						<td><input name='sp_description[]' id='spdescription$m' type='text' class='smallFields' value='$description' $disabled/></td>";
						
						
				if (stripos($telephonenumber, 'slot') !== false) {						
					echo" <td class='center'><img src='../assets/images/park.png' name='parkRow' class='parkRow cursor' title='Park Slots'/>";
				} else {
					echo" <td class='center'><img src='../assets/images/delete.png' name='deleteRow' class='delete deleteRow cursor' title='Delete Row'/>&nbsp;
					<img src='../assets/images/move.png' id='moveRow' name='moveRow' class='deleteRow move' title='Move Row'/>
					&nbsp;<img class='move' style='cursor:pointer' title='Move to Folder' alt='Move to Folder' src='../assets/images/moverow.png' />";
				}
						
				echo"</td></tr>";		
					}			
				}
				}
			?>	
			
					<tr id="996699" data-header='GH:996699' data-guid='996699' class="group_heading nodrag nopriority">
                        <td colspan="2"><img src='../assets/images/folder-icon.png'><input type='text' maxlength='16' id='groupNONE' value='Not In Folder' class='group_header' readonly></td>
                    </tr>			
					
                </tbody>
            </table>
			<br/><input type="button" class='button' name="addBtn" id="addBtn" value="Add Favourites" />&nbsp;<input type="button" class='button' name="addGrp" id="addGrp" value="Add Folder" />

		</form>
		
		</div>
		</div> 
	<!-- #left -->
				
		</div> <!-- scroller -->
      </li>
			<!-- firth tab -->
			
			<div class='formFooter'>
				<div class='left' id='msg_wrap'>
					<span id='msg'>
					<?php
						if (isset($disabled) && $disabled === '1') echo " Disabled User - Please Contact Your Reseller ";
					?>
					</span>
				</div>
			
				<div class='right'>

					<input type='button' class='close' id ='close' value='Close'/>
					<input type='button' class='save' id='save' value='Save'/>
				</div>
			</div>

		</ul>
    </div>
	
</div>	
</body>
</html>

<div id="message">
<div class='closemovegroup'>X</div>
<br>
	Move To Folder:<br>
	<span id='groupSelect'>
	<input type='hidden' id='moveRow' value='' />
	<select id='SelectGroup'>
	</select>
<br><br>
</span>
</div>
